jdk/src/share/classes/sun/security/krb5/KrbApReq.java
changeset 23346 c1437bb64131
parent 23010 6dadb192ad81
child 25522 10d789df41bb
--- a/jdk/src/share/classes/sun/security/krb5/KrbApReq.java	Thu Mar 13 15:13:22 2014 +0800
+++ b/jdk/src/share/classes/sun/security/krb5/KrbApReq.java	Fri Mar 14 09:29:16 2014 +0800
@@ -284,7 +284,7 @@
 
         if (dkey == null) {
             throw new KrbException(Krb5.API_INVALID_ARG,
-                "Cannot find key of appropriate type to decrypt AP REP - " +
+                "Cannot find key of appropriate type to decrypt AP-REQ - " +
                                    EType.toString(encPartKeyType));
         }
 
@@ -380,7 +380,7 @@
 
     /**
      * Returns the credentials that are contained in the ticket that
      * is part of this this AP-REP.
      */
     public Credentials getCreds() {
         return creds;
@@ -380,7 +380,7 @@
     /**
      * Returns the credentials that are contained in the ticket that
-     * is part of this this AP-REP.
+     * is part of this AP-REQ.
      */
     public Credentials getCreds() {